@@ -1,6 +1,8 @@
 from __future__ import annotations
 
-DIR_GIT = ".git"
+from pathlib import Path
+
+DIR_GIT = Path(".git")
 
 # filestate: python-constant-sort
 FILE_EXTENSION_ENV = "env"
@@ -8,7 +10,7 @@ FILE_EXTENSION_PYTHON = "py"
 FILE_EXTENSION_YAML = "yml"
 
 # filestate: python-constant-sort
-FILE_NAME_ENV = f".{FILE_EXTENSION_ENV}"
-FILE_NAME_ENV_YAML = f".{FILE_EXTENSION_ENV}.{FILE_EXTENSION_YAML}"
+FILE_NAME_ENV = Path(f".{FILE_EXTENSION_ENV}")
+FILE_NAME_ENV_YAML = Path(f".{FILE_EXTENSION_ENV}.{FILE_EXTENSION_YAML}")
 
 PATH_NAME_PATH = "path"
